/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */ 

package ws.ladder.db.common;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;

import ws.ladder.db.base.Artifact;
import ws.ladder.db.base.Id;

@Entity
public class PropertyBinding extends Id {
	
	private PropertyBindingType propertyBindingType;
	private Artifact artifact;
	private String artifactPropertyName;
	private Property property; // back reference

	public PropertyBinding() {
	}

	PropertyBinding(PropertyBindingType type, Artifact artifact, String artifactPropertyName) {
		this.propertyBindingType = type;
		this.artifact = artifact;
		this.artifactPropertyName = artifactPropertyName;
	}

	@ManyToOne(optional = false)
	public PropertyBindingType getPropertyBindingType() {
		return propertyBindingType;
	}

	public void setPropertyBindingType(PropertyBindingType propertyBindingType) {
		this.propertyBindingType = propertyBindingType;
	}

	@ManyToOne(optional = false)
	public Artifact getArtifact() {
		return artifact;
	}

	public void setArtifact(Artifact artifact) {
		this.artifact = artifact;
	}

	@Column(nullable = false)
	public String getArtifactPropertyName() {
		return artifactPropertyName;
	}

	public void setArtifactPropertyName(String artifactPropertyName) {
		this.artifactPropertyName = artifactPropertyName;
	}

	@ManyToOne(optional = false)
	public Property getProperty() {
		return property;
	}

	public void setProperty(Property property) {
		this.property = property;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = super.hashCode();
		result = prime * result + ((propertyBindingType == null) ? 0 : propertyBindingType.hashCode());
		result = prime * result + ((artifact == null) ? 0 : artifact.hashCode());
		result = prime * result + ((artifactPropertyName == null) ? 0 : artifactPropertyName.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (!super.equals(obj)) {
			if (!(obj instanceof PropertyBinding))
				return false;
			PropertyBinding other = (PropertyBinding) obj;
			if (propertyBindingType == null) {
				if (other.getPropertyBindingType() != null)
					return false;
			} else if (!propertyBindingType.equals(other.getPropertyBindingType()))
				return false;
			if (artifact == null) {
				if (other.getArtifact() != null)
					return false;
			} else if (artifact != other.getArtifact() && (artifact.getId() == null || !artifact.getId().equals(other.getArtifact().getId())) )
				return false;
			if (artifactPropertyName == null) {
				if (other.getArtifactPropertyName() != null)
					return false;
			} else if (!artifactPropertyName.equals(other.getArtifactPropertyName()))
				return false;
		}
		return true;
	}

}
