/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */ 

package ws.ladder.db.dao;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.Collection;
import java.util.List;

import javax.annotation.Resource;

import ws.ladder.service.DAOFactory;
import ws.ladder.service.DAOTemplate;

public class AbstractDAOTemplate<T> implements DAOTemplate<T> {
	@Resource(name="DAOFactory")
	private DAOFactory daoFactory; 

	private DAOTemplate<T> daoDelegate; 	

	@SuppressWarnings("unchecked")
	public DAOTemplate<T> getDelegate() {
		final Class<? extends T> persistentClass;
		
		Type type = ((ParameterizedType) getClass().getGenericSuperclass()).getActualTypeArguments()[0];
		if (type instanceof Class) {
			persistentClass = (Class<? extends T>) type;
		} else if (type instanceof TypeVariable) {
			persistentClass = (Class<? extends T>) ((java.lang.reflect.TypeVariable) type).getBounds()[0];
		} else {
			persistentClass = null;
		}

		if(daoDelegate == null) {
			daoDelegate = daoFactory.create();
			daoDelegate.setPersistentClass((T)persistentClass);
		}

		return daoDelegate;
	}

	@Override
	public T findById(Object id) {
		return getDelegate().findById(id);
	}

	@Override
	public T findByName(String name) {
		return getDelegate().findByName(name);
	}

	@Override
	public List<T> findByIds(Collection<Object> ids) {
		return getDelegate().findByIds(ids);
	}

	@Override
	public List<T> findAll() {
		return getDelegate().findAll();
	}

	@Override
	public T saveOrUpdate(T entity) {
		return getDelegate().saveOrUpdate(entity);
	}

	@Override
	public void delete(T entity) {
		getDelegate().delete(entity);
	}

	@Override
	public void refresh(T entity) {
		getDelegate().refresh(entity);
	}

	@Override
	public void clear() {
		getDelegate().clear();
	}

	@Override
	public void setPersistentClass(T clazz) {
		// This method is used in the delegate and does not have use here
	}
}
