/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */ 

package ws.ladder.db.option;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;

import ws.ladder.db.base.Identity;

@Entity
public class OptionSet extends Identity {

	private int maxOccurs = 1;

	private int minOccurs = 1;

	private Set<Option> options;

	private OptionModel optionModel;

	private int orderIndex;

	private boolean isInitialOrder;

	private boolean consumerReadOnly;

	private boolean consumerVisible;

	public int getMaxOccurs() {
		return this.maxOccurs;
	}

	public int getMinOccurs() {
		return this.minOccurs;
	}

	@OneToMany(mappedBy = "optionSet", cascade = { CascadeType.ALL }, orphanRemoval = true)
	public Set<Option> getOptions() {
		if (this.options == null) {
			this.options = new HashSet<Option>();
		}
		return this.options;
	}

	@ManyToOne
	public OptionModel getOptionModel() {
		return this.optionModel;
	}

	public int getOrderIndex() {
		return this.orderIndex;
	}

	public boolean getIsInitialOrder() {
		return this.isInitialOrder;
	}

	public boolean isConsumerReadOnly() {
		return consumerReadOnly;
	}

	public boolean isConsumerVisible() {
		return consumerVisible;
	}

	public void setMaxOccurs(int value) {
		this.maxOccurs = value;
	}

	public void setMinOccurs(int value) {
		this.minOccurs = value;
	}

	public void setOptions(Set<Option> value) {
		this.options = value;
	}

	public void setOptionModel(OptionModel value) {
		this.optionModel = value;
	}

	public void setOrderIndex(int value) {
		this.orderIndex = value;
	}

	public void setIsInitialOrder(boolean value) {
		this.isInitialOrder = value;
	}

	public void setConsumerReadOnly(boolean consumerReadOnly) {
		this.consumerReadOnly = consumerReadOnly;
	}

	public void setConsumerVisible(boolean consumerVisible) {
		this.consumerVisible = consumerVisible;
	}

}
