/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */ 

package ws.ladder.db.pm;

import java.util.Map;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.ManyToMany;
import javax.persistence.MapKey;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;

import ws.ladder.db.base.Identity;
import ws.ladder.db.base.Manager;

@Entity
public class Project extends Identity {	
	
	private FinancialSummary financialSummary;
	
	@OneToOne(mappedBy="project", cascade = CascadeType.ALL)	// example of a bi-directional OneToOne relationship
	public FinancialSummary getFinancialSummary() {
		return financialSummary;
	}

	public void setFinancialSummary(FinancialSummary financialSummary) {
		this.financialSummary = financialSummary;
	}		

	private Task rootTask;

	@OneToOne(cascade = CascadeType.ALL)
	public Task getRootTask() {
		return this.rootTask;
	}

	public void setRootTask(Task root) {
		this.rootTask = root;
	}

	private Set<Manager> managers;

	@ManyToMany(mappedBy="projects", cascade = CascadeType.ALL )
	public Set<Manager> getManagers() {
		return this.managers;
	}

	public void setManagers(Set<Manager> managers) {
		this.managers = managers;
	}
	
	private Map<String, Project> subProjects;

	@OneToMany(cascade = CascadeType.ALL )
	@MapKey(name="name")
	public Map<String, Project> getSubProjects() {
		return this.subProjects;
	}

	public void setSubProjects(Map<String, Project> subProjects) {
		this.subProjects = subProjects;
	}	
	
}
