/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.db.pm;

import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.OrderColumn;

import ws.ladder.db.base.Identity;
import ws.ladder.db.base.Person;

@Entity
public class Task extends Identity {	
		
	private Set<Task> taskChildren;

	@OneToMany(mappedBy="taskParent", cascade = CascadeType.ALL, orphanRemoval = true )
	public Set<Task> getTaskChildren() {
		return this.taskChildren;
	}

	public void setTaskChildren(Set<Task> taskChildren) {
		this.taskChildren = taskChildren;
	}
	
	private List<Task> dependencies;

	@OneToMany(cascade = CascadeType.ALL, orphanRemoval = true )
	@OrderColumn(name="dep_seq")
	public List<Task> getDependencies() {
		return this.dependencies;
	}

	public void setDependencies(List<Task> dependencies) {
		this.dependencies = dependencies;
	}	

	private Task taskParent;

	@ManyToOne
	public Task getTaskParent() {
		return this.taskParent;
	}

	public void setTaskParent(Task taskParent) {
		this.taskParent = taskParent;
	}

	private String taskUri;

	public void setTaskUri(String value) {
		this.taskUri = value;
	}
	public String getTaskUri() {
		return this.taskUri;
	}

	private Person assignedTo;
	
	@OneToOne
	public Person getAssignedTo() {
		return assignedTo;
	}

	public void setAssignedTo(Person assignedTo) {
		this.assignedTo = assignedTo;
	}
	
	private TaskDetails taskDetails;	
	
	@OneToOne(mappedBy="task")
	public TaskDetails getTaskDetails() {
		return taskDetails;
	}

	public void setTaskDetails(TaskDetails taskDetails) {
		this.taskDetails = taskDetails;
	}	
	
	private Task auditTask;	
	
	@OneToOne(mappedBy="auditedTask", cascade = CascadeType.ALL, orphanRemoval = true)
	public Task getAuditTask() {
		return auditTask;
	}	
	
	public void setAuditTask(Task audit) {
		this.auditTask = audit;
	}	
	
	// The task related to the audit
	private Task auditedTask;	
	
	@OneToOne
	public Task getAuditedTask() {
		return auditedTask;
	}	
	
	public void setAuditedTask(Task value) {
		this.auditedTask = value;
	}		

	private Quote quote;
	
	@OneToOne(mappedBy="task", cascade = CascadeType.ALL, optional = true, orphanRemoval = true)	
	public Quote getQuote() {
		return quote;
	}

	public void setQuote(Quote quote) {
		this.quote = quote;
	}
	
	private Date scheduledFinish;	
	
	public Date getScheduledFinish() {
		return scheduledFinish;
	}

	public void setScheduledFinish(Date scheduledFinish) {
		this.scheduledFinish = scheduledFinish;
	}
	
	@OneToOne	
	public Task getAlternateTask() {
		return alternateTask;
	}

	public void setAlternateTask(Task alternateTask) {
		this.alternateTask = alternateTask;
	}

	// The task related to the audit
	private Task alternateTask;
	
	private Person ownedBy;

	@ManyToOne
	public Person getOwnedBy() {
		return this.ownedBy;
	}

	public void setOwnedBy(Person ownedBy) {
		this.ownedBy = ownedBy;
	}	

}
