/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.db.service;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import ws.ladder.db.base.Person;
import ws.ladder.db.dao.PersonDao;


@Service("personService")
public class PersonServiceImpl implements PersonService {
	private static final Logger logger = LogManager.getLogger(new Exception()
			.getStackTrace()[0].getClassName());
	
	@Autowired private PersonDao personDao;	

	@Override
	@Transactional
	public Person createPerson(Person person) {
		logger.debug("Entering method createPerson(Person person).");

		person = personDao.saveOrUpdate(person); 

		return person;
	}

	@Override
	@Transactional
	public Person getPerson(String personId) {
		logger.debug("Entering method getPerson(String personId).");
		Person person = personDao.findById(personId);

		return person;
	}

}
