/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.model.operation;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;


import ws.ladder.model.CallInfo;
import ws.ladder.model.ExtendedDataObject;
import ws.ladder.model.view.Query;
import ws.ladder.model.view.QueryBuilder;
import ws.ladder.model.view.ViewBranch;
import ws.ladder.util.ClassUtil;

public class QueryOperation extends AbstractOperation {

	private List<Object> result = new ArrayList<Object>();

	@Override
	protected void processInvariants(CallInfo callInfo) {
		// Invariants do not need to be run since this operation does not modify data
	}

	@Override
	public void execute(CallInfo callInfo) {
		ExtendedDataObject sourceEntity = (ExtendedDataObject) callInfo.getSource();
		QueryBuilder qb = sourceEntity.getObjectCreator().getDAS().getQueryBuilder();
		
		qb.init((ExtendedDataObject) callInfo.getTarget(), callInfo.getSettings().getView().getEntityView(sourceEntity.getType(), callInfo.getSettings().doNarrow()));	// Put in loop for multiple views
		Query query = qb.createQuery(callInfo);

		Map<ExtendedDataObject, Object> uniqueList = new LinkedHashMap<ExtendedDataObject, Object>();		
		try {
			// club all the results relevant to the same entity
			// add an id attribute for the mail entity. Add an owner attribute for each collection property referenced.
			// adjust the properties and for every new attribute added (id or owner) create a filler/dummy property column in the view
			ViewBranch aggregateView = callInfo.getSettings().getView().getEntityView( ((ExtendedDataObject) callInfo.getTarget()).getType(), callInfo.getSettings().doNarrow() );
			if(aggregateView.isCrossAggregate() && !callInfo.getSettings().permitCrossAggregate())
				throw new RuntimeException("The view crosses aggregate boundary, this could be a security risk. If this is intentional then permit this by modifying the settings");
			
			for(Object obj: query.getResultList(aggregateView)) {
				ExtendedDataObject newRootObject = aggregateView.getQueryRoot(obj, (ExtendedDataObject) callInfo.getTarget());

				if(ClassUtil.getDimensionCount(obj) == 1) {
					aggregateView.normalize(newRootObject, (Object[])obj);
					if(newRootObject.getContainer() == null) // Only add root objects
						uniqueList.put(newRootObject, null);
				}
			}
		} catch (Exception e) {
			throw ClassUtil.wrapRun(e);
		}
		
		// Do a second pass
		for(ExtendedDataObject root: uniqueList.keySet())
			if(root.getContainer() == null) // Only add root objects
				result.add(root);
	}	

	@Override
	public Object getResult() {
		return result;
	}		
}
