/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.model.view;


import ws.ladder.model.Settings;
import ws.ladder.service.QueryCapability;


public class ColumnMeta {

	protected String attributePath;      // The full name of the property
	protected ViewProperty viewProperty; // A view property can be associated with multiple ColumnMeta
	protected int position;              // position of this column in the result table

	public ColumnMeta(String attributePath, ViewProperty viewProperty) {
		this.attributePath = attributePath;
		this.viewProperty = viewProperty;
	}
	
	@Override
	public int hashCode() {
		int result = 17;
		result = 37 * result + System.identityHashCode(attributePath);
		return result;
	}

	@Override
	public boolean equals(Object other) {
		ColumnMeta otherKey = (ColumnMeta) other;
		return otherKey.attributePath == this.attributePath;
	}	
		
	public boolean isDependent() {
		// Is this property dependent on its parent. This is true for all special properties, i.e., those that end with the PATH_DELIMITER
		return attributePath.endsWith(Settings.URI_PATH_DELIMITER);
	}

	public String getQueryString(QueryCapability queryCapability) {

		String result = viewProperty.getAlias();

		if(attributePath.endsWith(ViewProperty.ENTITYNAME_ATTRIBUTE))
			throw new RuntimeException("Narrowing of the entity is supported only if the whole entity object is retrieved, which we don't support. Use native query instead.");
			//result = queryCapability.getTypeMechanism(viewProperty.getAlias());
		else if(attributePath.endsWith(ViewProperty.LIST_INDEX_ATTRIBUTE))
			result = queryCapability.getListIndexMechanism(viewProperty.getAlias());
		else if(attributePath.endsWith(ViewProperty.MAP_KEY_ATTRIBUTE))
			result = queryCapability.getMapKeyMechanism(viewProperty.getAlias());		
		else if(result == null) { // no alias
			if(viewProperty.getParent() != null)
				result = viewProperty.getParent().getAlias() + viewProperty.getPropertyPath().substring(viewProperty.getParent().getPropertyPath().length());
			else
				result = viewProperty.getPropertyPath();
		}

		return result;
	}	

	public int getPosition() {
		return position;
	}

	public void setPosition(int position) {
		this.position = position;
	}	

	public String getAttributePath() {
		return attributePath;
	}	

	public ViewProperty getViewProperty() {
		return viewProperty;
	}
	
	public void setViewProperty(ViewProperty viewProperty) {
		this.viewProperty = viewProperty;
	}	

	public Integer getAttributeLevel() {
		int noOfSteps = 0;
		for(int delimPos = attributePath.indexOf(Settings.PATH_DELIMITER, 0); delimPos != -1; delimPos = attributePath.indexOf(Settings.PATH_DELIMITER, delimPos+1))
			noOfSteps++;
		
		return noOfSteps;
	}	
}