/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.model.view;

import java.io.InputStream;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;

public class ContentViewFactory {
	private static final Logger logger = LogManager.getLogger(new Exception().getStackTrace()[0].getClassName());
	private static String CONTENT_VIEW_FILE = "ContentViews.xml";

	public void load() {
		load(CONTENT_VIEW_FILE);
	}
	
	public void load(String fileName) {
		ContentViews views = new ContentViews();

		try {
			InputStream stream = this.getClass().getClassLoader().getResourceAsStream(fileName);
			if(stream == null) {
				logger.warn("Unable to find the view configuration file: " + fileName);
				return;
			}
			
			JAXBContext jaxbContext = JAXBContext.newInstance(ContentViews.class);
			Unmarshaller jaxbUnmarshaller = jaxbContext.createUnmarshaller();

			views = (ContentViews) jaxbUnmarshaller.unmarshal(stream);
			views.sync();
			
		} catch (JAXBException e) {
			throw new RuntimeException("Unable to read " + fileName, e);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}