/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.model.view;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

@XmlRootElement(name="ContentViews")
public class ContentViews {
	private static volatile long lastSync = 0;

	@XmlTransient
	private static Map<String, ContentView> views = new ConcurrentHashMap<String, ContentView>();
	
	private Set<ContentView> contentView;
	
	public static List<String> getViewNames() {
		return new ArrayList<String>(views.keySet());
	}
	
	public Set<ContentView> getContentView() {
		return contentView;
	}

	public void setContentView(Set<ContentView> contentView) {
		this.contentView = contentView;
	}

	public static ContentView getView(String viewName) {
		return views.get(viewName);
	}
	
	public boolean containsView(String viewName) {
		return views.containsKey(viewName);
	}
	
	public static boolean isSynced() {
		return lastSync != 0;
	}
	
	/**
	 * Obsolete views will be left as is, and new or updated views will be set 
	 */
	public void sync() {
		lastSync = (new Date()).getTime();
		
		// merge the new views with existing views
		synchronized (views) {
			for(ContentView newView: contentView) {
				views.put(newView.getName(), newView);
			}
		}
	}
}