/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.model.view;

import java.util.Map;

import ws.ladder.model.view.expression.AbstractFunctionExpression;
import ws.ladder.model.view.expression.ExpressionFactory;

public class Filter {

	protected String expression;
	
	protected AbstractFunctionExpression functionExpression;

	public AbstractFunctionExpression getFunctionExpression() {
		return functionExpression;
	}

	public void setFunctionExpression(AbstractFunctionExpression functionExpression) {
		this.functionExpression = functionExpression;
	}

	public Filter narrow() {
		Filter result = new Filter();
		result.setExpression(expression);
		result.init();
		
		return result;
	}
	
	public void init() {
		this.functionExpression = ExpressionFactory.getExpression(expression);
		this.functionExpression.init();
	}
	
	public boolean isOrderBy() {
		return functionExpression.isOrderBy();
	}
	
	public String getQueryString() {
		return functionExpression.getQueryString();
	}
	
	public String getNormalizedName() {
		return functionExpression.getNormalizedAttributeName();
	}
	
	public String getParameterName() {
		return functionExpression.getParameterName();
	}

	public String getExpression() {
		return expression;
	}

	public void setExpression(String expression) {
		this.expression = expression;
	}

	public String getAttribute() {
		return functionExpression.getAttributeName();
	}

	public void normalize(Map<String, String> normalizedNames) {
		functionExpression.normalize(normalizedNames);
	}

	public Object getNormalizedValue(Object object) {
		return functionExpression.getNormalizedValue(object);
	}	
}
