/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.service;

import java.util.Collection;
import java.util.List;

public interface DAOTemplate<T> {
	/**
	 * Find the entity by its primary key
	 * @param id
	 * @return
	 */
    T findById(Object id);    
    
    /**
     * Find an entity by the "name" property
     * 
     * @param name
     * @return
     */
	T findByName(String name); 
	
	/**
	 * Find a list of entities by its primary key
	 * @param ids
	 * @return
	 */
    List<T> findByIds(Collection<Object> ids);
    
    /**
     * Get a list of all the instances of an entity type
     * @return
     */
    List<T> findAll();
    
    /**
     * Save the entity in the database
     * @param entity
     * @return
     */
    T saveOrUpdate(T entity);
    
    /**
     * Delete the entity from the database
     * @param entity
     */
    void delete(T entity);
    
    /**
     * refresh the state of the instance from the database
     * @param entity
     */
    public void refresh(T entity);
    
    /**
     * Clear all the managed entities from the cache, thus making them all detached
     */
    public void clear();
    
    /**
     * Set the java class of the entity
     * @param clazz
     */
    public void setPersistentClass(T clazz);
}