/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.service;

import java.util.List;

import ws.ladder.model.CallInfo;
import ws.ladder.model.Type;
import ws.ladder.model.TypeMapper;
import ws.ladder.model.view.QueryBuilder;

/**
 * 
 * @author Dilip Dalton
 *
 */
public interface DataAccessService {
	/**
	 * Build the Type and Property objects for the static API
	 */
	public void define();
	
	/**
	 * Return the type associated with a particular DataObject
	 * @param The java class whose Type object we need
	 * @return The Type object
	 */
	public Type getType(Class<?> clazz);
	
	/**
	 * Returns the Derived type for this class
	 * @param clazz
	 * @return
	 */
	public Type getDerivedType(Class<?> clazz);		
	
	/**
	 * Get the type first by looking for the class name and then fall-back to the entity name
	 * @param name
	 * @return
	 */
	public Type getType(String name);

	
	/**
	 * Return all the types managed by this service
	 */
	public List<Type> getTypes();
	
	/**
	 * This method uses the persistence mechanism to do any post-processing activity
	 * @param newInstance
	 * @return
	 */
	public void postProcess(Object newInstance);
	
	/**
	 * Check if there is an existing persistent instance with the identifier 
	 * specified in object
	 * 
	 * @param object
	 * @return A persistent object or null 
	 */
	public Object getPersistentObject(CallInfo callInfo, TypeMapper typeMapper);
	
	/**
	 * Returns the orchestrator responsible for updating/inserting/deleting data from the persistence store
	 * @return
	 */
	public PersistenceOrchestrator getPersistenceOrchestrator();
	
	/**
	 * Sets the persistence orchestrator for this Data access service. The orchestrator is responsible
	 * for mediating with the data store using the appropriate persistence mechanisms.
	 * 
	 * @param persistenceOrchestrator
	 */
	void setPersistenceOrchestrator(PersistenceOrchestrator persistenceOrchestrator);	
	
	/**
	 * The mapper used for creating the derived types
	 * @return
	 */
	public TypeMapper getTypeMapper();
	
	/**
	 * Gets the builder responsible for forming queries
	 * @return
	 */
	public QueryBuilder getQueryBuilder();
	
	/**
	 * Lists the names of the aggregates
	 * @return
	 */
	public List<String> getAggregateList();

}