/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.service;

import java.io.Serializable;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.springframework.beans.factory.annotation.Autowired;

public class HibernatePersistenceOrchestrator extends AbstractPersistenceOrchestrator {

	@Autowired
	private SessionFactory sessionFactory;    

	protected Session getSession() {
		if (this.sessionFactory.getCurrentSession() == null)
			throw new IllegalStateException("Session has not been set on DAO before usage");
		return this.sessionFactory.getCurrentSession();
	}    	

	/**
	 * Save the entity in the persistence store
	 * 
	 * @param entity
	 * @return
	 */
	@Override
	public void saveOrUpdate(Object entity) {
		getSession().saveOrUpdate(entity);		
	}

	/**
	 * Delete the entity from the persistence store
	 * 
	 * @param entity
	 */
	@Override
	public void delete(Object entity) {
		getSession().delete(entity);		
	}

	@Override
	public void flush() {
		getSession().flush();
	}

	@Override
	public Object findById(Class<?> persistentClass, Object id) {
	   return getSession().load(persistentClass, (Serializable) id);
	}

	@Override
	public QueryCapability getQueryCapability() {
		return new JPAQueryCapability();
	}

}