/**
 * Ladder, empowering Model Driven Architecture in J2EE applications
 *
 * Copyright (c) 2012, Dilip Dalton or third-party contributors as
 * indicated by the @author tags.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * Ladder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution. If not, see <http://www.gnu.org/licenses/>.
 */

package ws.ladder.service;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.BeanCreationException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.AutowireCapableBeanFactory;
import org.springframework.stereotype.Component;

@Component("DAOFactory")
public class SpringDAOFactory implements DAOFactory {
	private static final Logger logger = LogManager.getLogger(new Exception().getStackTrace()[0].getClassName());

	@Autowired
	protected AutowireCapableBeanFactory beanFactory;

	public <T> DAOTemplate<T> create() {
			DAOTemplate<T> result = null;

			try { // HibernateDAS
				result = new HibernateDAOTemplate<T>();
				beanFactory.autowireBean(result);
				return result;
			} catch(BeanCreationException e) {
				logger.warn("Hibernate configuration not found, hence cannot create a HibernateDAOTemplate instance");				
			}		
			
			try { // JPADataAccessService
				result = new JPADAOTemplate<T>();
				beanFactory.autowireBean(result);
				return result;					
			} catch (BeanCreationException e) {
				logger.warn("JPA configuration not found, hence cannot create a JPADAOTemplate instance");
			}
			
			return null;
	}

}
